@@ -16,8 +16,8 @@
 ;; Author: Yad Tahir <yad at ieee.org>
 ;; URL: https://github.com/yad-tahir/org-roam-latte
 ;; Package-Requires: ((emacs "27.1") (org-roam "2.0") (inflections "1.1"))
-;; Package-Version: 20260213.555
-;; Package-Revision: 28df5361d8b9
+;; Package-Version: 20260220.1741
+;; Package-Revision: 6b25996f9930
 ;; Description: Auto-highlight unlinked Org-roam references
 ;; Keywords: hypermedia, outlines, org-roam, convenience
 
@@ -201,12 +201,24 @@ Return nil if the overlay cannot be converted."
 
 (defun org-roam-latte--has-common-tag-p (keyword-nodes node)
   "Return non-nil if NODE shares a tag with KEYWORD-NODES or has no tags."
-  (let ((node-tags (org-roam-node-tags node)))
-    (or (null node-tags)
-        (cl-loop for node in keyword-nodes
-                 thereis (cl-intersection (org-roam-node-tags node)
-                                          node-tags
-                                          :test #'string=)))))
+  (when node
+    (let ((node-tags (org-roam-node-tags node)))
+      (or (null node-tags)
+          (cl-loop for node in keyword-nodes
+                   thereis (cl-intersection (org-roam-node-tags node)
+                                            node-tags
+                                            :test #'string=))))))
+
+(defun org-roam-latte--member (node nodes)
+  "Return non-nil if NODE is a member of the list NODES.
+
+Membership is tested by comparing the `org-roam-node-id' of NODE
+against the ID of each element in NODES.  Like standard `member',
+this returns the tail of NODES starting with the matching element."
+  (cl-member (org-roam-node-id node)
+             nodes
+             :key #'org-roam-node-id
+             :test #'string=))
 
 (defun org-roam-latte--check-ancestors (keyword-nodes scope)
   "Check ancestor lineage against KEYWORD-NODES using SCOPE rules."
@@ -218,7 +230,7 @@ Return nil if the overlay cannot be converted."
                     do (goto-char (org-element-property :begin parent))
                     for parent-node = (org-roam-node-at-point)
                     ;; Exclude if parent is the source of the keyword
-                    if (member parent-node keyword-nodes)
+                    if (org-roam-latte--member parent-node keyword-nodes)
                     return t
                     ;; Exclude if strict tags are on and tags don't match
                     if (and check-tags-p
@@ -263,13 +275,12 @@ the rules set by `org-roam-latte-exclude-scope' and
             (pcase scope
               ('nil t)
               ('node
-               (not (member current-node keyword-nodes)))
+               (not (org-roam-latte--member current-node keyword-nodes)))
               ('tags
                (org-roam-latte--has-common-tag-p keyword-nodes current-node))
               ('node-tags
-               (and (not (member current-node keyword-nodes))
-                    (org-roam-latte--has-common-tag-p
-                     keyword-nodes current-node)))
+               (and (not (org-roam-latte--member current-node keyword-nodes))
+                    (org-roam-latte--has-common-tag-p keyword-nodes current-node)))
               ((or 'parents 'parents-tags)
                (org-roam-latte--check-ancestors keyword-nodes scope)))))))
      ;; By default
@@ -423,7 +434,8 @@ Otherwise, nil."
   "Add PHRASE and its plural form as keywords to the `org-roam-latte--keywords'.
 
 Stores NODE in a list as a text property 'nodes on the KEYWORD string."
-  (when (and phrase (not (string-blank-p phrase)))
+  (when (and phrase
+             (not (string-blank-p phrase)))
     (unless (member phrase org-roam-latte-exclude-words)
       (let* ((key (downcase phrase))
              (value (or (gethash key org-roam-latte--keywords)
@@ -431,9 +443,7 @@ Stores NODE in a list as a text property 'nodes on the KEYWORD string."
              (nodes (get-text-property 0 'nodes value))
              (singularize (org-roam-latte--singularize key)))
         ;; Compare by ID
-        (unless (cl-member (org-roam-node-id node) nodes
-                           :key #'org-roam-node-id
-                           :test #'string=)
+        (unless (org-roam-latte--member node nodes)
           (push node nodes))
         (put-text-property 0 (length value) 'nodes nodes value)
 
@@ -576,7 +586,7 @@ WIN The window object in which the scroll event has occurred."
   (let* ((keyword (org-roam-latte--keyword-at-point))
          (nodes (get-text-property 0 'nodes keyword)))
     (when nodes
-      (member node nodes))))
+      (org-roam-latte--member node nodes))))
 
 ;;
 ;; Public functions
